@@ -1,8 +1,6 @@
 /* SOGoSource.h - this file is part of SOGo
  *
- * Copyright (C) 2009-2012 Inverse inc.
- *
- * Author: Ludovic Marcotte <lmarcotte@inverse.ca>
+ * Copyright (C) 2009-2022 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +24,8 @@
 
 #import "SOGoConstants.h"
 
+@class EOQualifier;
+@class EOSortOrdering;
 @class NSDictionary;
 @class NSException;
 @class NSString;
@@ -40,6 +40,11 @@
 
 - (NSString *) domain;
 - (NSArray *) searchFields;
+- (NSArray *) userPasswordPolicy;
+
+- (id) connection;
+- (void) releaseConnection: (id) connection;
+- (BOOL) isConnected;
 
 /* requires a "." to obtain the full list of contacts */
 - (void) setListRequiresDot: (BOOL) aBool;
@@ -58,6 +63,9 @@
 
 - (NSDictionary *) lookupContactEntry: (NSString *) theID
                              inDomain: (NSString *) domain;
+- (NSDictionary *) lookupContactEntry: (NSString *) theID
+                             inDomain: (NSString *) domain
+		      usingConnection: (id) connection;
 - (NSDictionary *) lookupContactEntryWithUIDorEmail: (NSString *) entryID
                                            inDomain: (NSString *) domain;
 
@@ -66,6 +74,9 @@
 - (NSArray *) fetchContactsMatching: (NSString *) filter
                        withCriteria: (NSArray *) criteria
                            inDomain: (NSString *) domain;
+- (NSArray *) lookupContactsWithQualifier: (EOQualifier *) qualifier
+                          andSortOrdering: (EOSortOrdering *) ordering
+                                 inDomain: (NSString *) domain;
 
 - (void) setSourceID: (NSString *) newSourceID;
 - (NSString *) sourceID;
@@ -84,6 +95,9 @@
 - (NSException *) updateContactEntry: (NSDictionary *) ldifRecord;
 - (NSException *) removeContactEntryWithID: (NSString *) aId;
 
+- (void) addVCardProperty: (NSString *) property
+               toCriteria: (NSMutableArray *) criteria;
+
 /* user address books */
 - (NSArray *) addressBookSourcesForUser: (NSString *) user;
 
@@ -118,4 +132,10 @@
 - (void) updateBaseDNFromLogin: (NSString *) theLogin;
 @end
 
+@protocol SOGoMembershipSource <SOGoSource>
+- (NSArray *) membersForGroupWithUID: (NSString *) uid;
+- (BOOL) groupWithUIDHasMemberWithUID: (NSString *) uid
+                            memberUid: (NSString *) memberUid;
+@end
+
 #endif /* SOGOSOURCE_H */
