@@ -6,8 +6,8 @@
   /**
    * @ngInject
    */
-  ComponentController.$inject = ['$rootScope', '$scope', '$q', '$mdDialog', 'Preferences', 'Calendar', 'Component', 'AddressBook', 'Account', 'stateComponent'];
-  function ComponentController($rootScope, $scope, $q, $mdDialog, Preferences, Calendar, Component, AddressBook, Account, stateComponent) {
+  ComponentController.$inject = ['$rootScope', '$scope', '$q', '$mdDialog', 'sgConstant', 'Preferences', 'Calendar', 'Component', 'AddressBook', 'Account', 'stateComponent'];
+  function ComponentController($rootScope, $scope, $q, $mdDialog, sgConstant, Preferences, Calendar, Component, AddressBook, Account, stateComponent) {
     var vm = this, component;
 
     this.$onInit = function () {
@@ -278,6 +278,13 @@
         this.showRecurrenceEditor = true;
     };
 
+    this.destinationCalendars = function () {
+      if (this.component.isErasable)
+        return Calendar.$findAll(null, true, this.component.pid);
+      else
+        return [Calendar.$get(this.component.pid)];
+    };
+
     this.changeCalendar = function () {
       var updateRequired = (this.component.attendees && this.component.attendees.length > 0);
       if (updateRequired)
@@ -294,12 +301,11 @@
           destinationCalendar = Calendar.$get(this.component.destinationCalendar),
           options = initOrganizer? { organizerCalendar: destinationCalendar } : {},
           promises = [];
-      var emailRE = /([\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+\.)*[\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+@((((([a-z0-9]{1}[a-z0-9\-]{0,62}[a-z0-9]{1})|[a-z])\.)+[a-z]{2,})|(\d{1,3}\.){3}\d{1,3}(\:\d{1,5})?)/i,
-          i, address;
+      var i, address;
       if (partial) options.partial = partial;
 
       function createCard(str) {
-        var match = str.match(emailRE),
+        var match = str.match(String.emailRE),
             email = match[0],
             name = str.replace(new RegExp(" *<?" + email + ">? *"), '');
         vm.showAttendeesEditor |= initOrganizer;
@@ -333,7 +339,7 @@
                card.charCodeAt(i) == 32 ||   // space
                card.charCodeAt(i) == 44 ||   // ,
                card.charCodeAt(i) == 59) &&  // ;
-              emailRE.test(address)) {
+              String.emailRE.test(address)) {
             promises.push(createCard(address).then(addCard));
             address = '';
           }
@@ -341,7 +347,7 @@
             address += card.charAt(i);
           }
         }
-        if (address && emailRE.test(address)) {
+        if (address && String.emailRE.test(address)) {
           promises.push(createCard(address).then(addCard));
         }
       }
@@ -424,7 +430,7 @@
             '</md-toast>'
           ].join(''),
           hideDelay: 5000,
-          position: 'top right'
+          position: sgConstant.toastPosition
         });
       }).finally(function () {
         $timeout(scrollToStart);
